@@ -63,6 +63,28 @@ class AskdataPandasExtension:
         self._token = r1.json()['access_token']
         self.r1 = r1
 
+    def normalize_columns(self):
+
+        problematicChars = [",", ";", ":", "{", "}", "(", ")", "=", ">", "<", "."]
+        new_cols = {}
+        for column in self._df.columns:
+
+            columnName = column.lower()
+
+            for p_char in problematicChars:
+                columnName = columnName.replace(p_char, "")
+
+            columnName = columnName.replace(" ", "_")
+            columnName = columnName.replace("-", "_")
+            columnName = columnName.strip()
+
+            for p_char in problematicChars:
+                columnName = columnName.replace(p_char, "")
+
+            new_cols[column] = columnName
+
+        return self._df.rename(columns=new_cols, inplace=True)
+
 
     def save_dataset(self, workspace:str, dataset_slug="", replace=False, dataset_name="", locale="en"):
 
