@@ -137,18 +137,18 @@ class Insight_Definition:
 
         settings = {}
         for field in field_codes.keys():
-            ids = []
             for column in columns:
                 if(column["code"] in field_codes[field] or column["name"] in field_codes[field]):
                     for query in query_ids:
                         if(str(field_codes[field]).startswith(query)):
                            if(str(column["id"]).startswith(query)):
-                               ids.append(column["id"])
+                               settings[field + "_id"] = column["id"]
+                               break
                            else:
                                continue
                         else:
-                            settings[field + "_id"] = ids.append(column["id"])
-
+                            settings[field + "_id"] = column["id"]
+                            break
 
         for key in values.keys():
             settings[key + "_id"] = values[key]
@@ -167,10 +167,74 @@ class Insight_Definition:
             "valid": True,
             "queryComponent": False
         }
-        print(body)
         r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
+    def add_widget_test(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[]):
+        position = (len(self.components))
+        widget_id = self.__create_widget(position, widget_type)
+        if(query_ids!=[]):
+            self.edit_widget_test(widget_id, widget_type,query_ids, settings, values, texts, charts)
+        return widget_id
+
+    def edit_widget_test(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
+
+        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/widgets/"+widget_id
+        columns = []
+        for query in query_ids:
+            if query.startswith("qcomp"):
+
+                qc = self.get_component(query)
+                url_preview = self.smart_insight_url + "/composed_queries/" + qc["settings"]["qc"] + "/preview?limit=100&agentId=" + self.agent_id
+                r = self.__make_post_request(url_preview, {})
+                cols = r.json()["schema"]
+                for col in cols:
+                    if(query not in ((str)(col["id"]))):
+                        col["id"] = query + "-" +col["id"]
+                    columns.append(col)
+                #cols = self.get_columns(query_ids)
+            else:
+                cols = self.get_columns(query_ids)
+                for col in cols:
+                    columns.append(col)
+
+        settings = {}
+        for field in field_codes.keys():
+            ids = []
+            for column in columns:
+
+                if(column["code"] in field_codes[field] or column["name"] in field_codes[field]):
+                    for query in query_ids:
+                        if(str(field_codes[field]).startswith(query)):
+                           if(str(column["id"]).startswith(query)):
+                               ids.append(column["id"])
+                           else:
+                               continue
+                        else:
+                            ids.append(column["id"])
+            settings[field + "_id"] = ids
+
+        for key in values.keys():
+            settings[key + "_id"] = values[key]
+
+        body = {
+            "id" : widget_id,
+            "type": "widget",
+            "name": "Widget",
+            "customName": False,
+            "dependsOn": [],
+            "widgetType": widget_type,
+            "queryIds": query_ids,
+            "settings": settings,
+            "texts": texts,
+            "charts": charts,
+            "valid": True,
+            "queryComponent": False
+        }
+        r = self.__make_put_request(url, body)
+        self.components = r.json()["components"]
+
+
     def get_columns(self, query_ids) -> list:
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/queries/columns"
