@@ -146,7 +146,10 @@ def get_aircall_calls(token, api_key, #mandatory
 
     for unix_col in unix_to_readable:
 
-        aircall_calls[unix_col] = pd.to_datetime(aircall_calls[unix_col], unit='s')
+        #aircall_calls[unix_col] = pd.to_datetime(aircall_calls[unix_col], unit='s')
+        
+        #convert to italian timezone
+        aircall_calls[unix_col] = pd.to_datetime(aircall_calls[unix_col], unit='s', utc=True, ).dt.tz_convert('Europe/Rome').dt.tz_localize(None)
 
     
     return aircall_calls
